==> happy-dom-1.11.2.tgz: package/src/config/ElementClass.ts <==
import HTMLTemplateElement from '../nodes/html-template-element/HTMLTemplateElement';
import HTMLFormElement from '../nodes/html-form-element/HTMLFormElement';
import HTMLElement from '../nodes/html-element/HTMLElement';
import HTMLInputElement from '../nodes/html-input-element/HTMLInputElement';
import HTMLTextAreaElement from '../nodes/html-text-area-element/HTMLTextAreaElement';
import SVGSVGElement from '../nodes/svg-element/SVGSVGElement';
import SVGElement from '../nodes/svg-element/SVGElement';

export default {
	HTMLTemplateElement: HTMLTemplateElement,
	HTMLFormElement: HTMLFormElement,
	HTMLInputElement: HTMLInputElement,
	HTMLTextAreaElement: HTMLTextAreaElement,
	HTMLElement: HTMLElement,
	HTMLHeadElement: HTMLElement,
	HTMLTitleElement: HTMLElement,
	HTMLBaseElement: HTMLElement,
	HTMLLinkElement: HTMLElement,
	HTMLMetaElement: HTMLElement,
	HTMLStyleElement: HTMLElement,
	HTMLBodyElement: HTMLElement,
	HTMLHeadingElement: HTMLElement,
	HTMLParagraphElement: HTMLElement,
	HTMLHRElement: HTMLElement,
	HTMLPreElement: HTMLElement,
	HTMLUListElement: HTMLElement,
	HTMLOListElement: HTMLElement,
	HTMLLIElement: HTMLElement,
	HTMLMenuElement: HTMLElement,
	HTMLDListElement: HTMLElement,
	HTMLDivElement: HTMLElement,
	HTMLAnchorElement: HTMLElement,
	HTMLAreaElement: HTMLElement,
	HTMLBRElement: HTMLElement,
	HTMLButtonElement: HTMLElement,
	HTMLCanvasElement: HTMLElement,
	HTMLDataElement: HTMLElement,
	HTMLDataListElement: HTMLElement,
	HTMLDetailsElement: HTMLElement,
	HTMLDialogElement: HTMLElement,
	HTMLDirectoryElement: HTMLElement,
	HTMLFieldSetElement: HTMLElement,
	HTMLFontElement: HTMLElement,
	HTMLHtmlElement: HTMLElement,
	HTMLImageElement: HTMLElement,
	HTMLLabelElement: HTMLElement,
	HTMLLegendElement: HTMLElement,
	HTMLMapElement: HTMLElement,
	HTMLMarqueeElement: HTMLElement,
	HTMLMediaElement: HTMLElement,
	HTMLMeterElement: HTMLElement,
	HTMLModElement: HTMLElement,
	HTMLOptGroupElement: HTMLElement,
	HTMLOptionElement: HTMLElement,
	HTMLOutputElement: HTMLElement,
	HTMLPictureElement: HTMLElement,
	HTMLProgressElement: HTMLElement,
	HTMLQuoteElement: HTMLElement,
	HTMLScriptElement: HTMLElement,
	HTMLSelectElement: HTMLElement,
	HTMLSlotElement: HTMLElement,
	HTMLSourceElement: HTMLElement,
	HTMLSpanElement: HTMLElement,
	HTMLTableCaptionElement: HTMLElement,
	HTMLTableCellElement: HTMLElement,
	HTMLTableColElement: HTMLElement,
	HTMLTableElement: HTMLElement,
	HTMLTimeElement: HTMLElement,
	HTMLTableRowElement: HTMLElement,
	HTMLTableSectionElement: HTMLElement,
	HTMLUnknownElement: HTMLElement,
	HTMLFrameElement: HTMLElement,
	HTMLFrameSetElement: HTMLElement,
	HTMLIFrameElement: HTMLElement,
	HTMLEmbedElement: HTMLElement,
	HTMLObjectElement: HTMLElement,
	HTMLParamElement: HTMLElement,
	HTMLVideoElement: HTMLElement,
	HTMLAudioElement: HTMLElement,
	HTMLTrackElement: HTMLElement,
	SVGSVGElement: SVGSVGElement,
	SVGElement: SVGElement
};

==> happy-dom-2.1.4.tgz: package/src/config/ElementClass.ts <==
import HTMLTemplateElement from '../nodes/html-template-element/HTMLTemplateElement';
import HTMLFormElement from '../nodes/html-form-element/HTMLFormElement';
import HTMLElement from '../nodes/html-element/HTMLElement';
import HTMLInputElement from '../nodes/html-input-element/HTMLInputElement';
import HTMLTextAreaElement from '../nodes/html-text-area-element/HTMLTextAreaElement';
import SVGSVGElement from '../nodes/svg-element/SVGSVGElement';
import SVGElement from '../nodes/svg-element/SVGElement';
import HTMLScriptElement from '../nodes/html-script-element/HTMLScriptElement';

export default {
	HTMLTemplateElement: HTMLTemplateElement,
	HTMLFormElement: HTMLFormElement,
	HTMLInputElement: HTMLInputElement,
	HTMLTextAreaElement: HTMLTextAreaElement,
	HTMLElement: HTMLElement,
	HTMLHeadElement: HTMLElement,
	HTMLTitleElement: HTMLElement,
	HTMLBaseElement: HTMLElement,
	HTMLLinkElement: HTMLElement,
	HTMLMetaElement: HTMLElement,
	HTMLStyleElement: HTMLElement,
	HTMLBodyElement: HTMLElement,
	HTMLHeadingElement: HTMLElement,
	HTMLParagraphElement: HTMLElement,
	HTMLHRElement: HTMLElement,
	HTMLPreElement: HTMLElement,
	HTMLUListElement: HTMLElement,
	HTMLOListElement: HTMLElement,
	HTMLLIElement: HTMLElement,
	HTMLMenuElement: HTMLElement,
	HTMLDListElement: HTMLElement,
	HTMLDivElement: HTMLElement,
	HTMLAnchorElement: HTMLElement,
	HTMLAreaElement: HTMLElement,
	HTMLBRElement: HTMLElement,
	HTMLButtonElement: HTMLElement,
	HTMLCanvasElement: HTMLElement,
	HTMLDataElement: HTMLElement,
	HTMLDataListElement: HTMLElement,
	HTMLDetailsElement: HTMLElement,
	HTMLDialogElement: HTMLElement,
	HTMLDirectoryElement: HTMLElement,
	HTMLFieldSetElement: HTMLElement,
	HTMLFontElement: HTMLElement,
	HTMLHtmlElement: HTMLElement,
	HTMLImageElement: HTMLElement,
	HTMLLabelElement: HTMLElement,
	HTMLLegendElement: HTMLElement,
	HTMLMapElement: HTMLElement,
	HTMLMarqueeElement: HTMLElement,
	HTMLMediaElement: HTMLElement,
	HTMLMeterElement: HTMLElement,
	HTMLModElement: HTMLElement,
	HTMLOptGroupElement: HTMLElement,
	HTMLOptionElement: HTMLElement,
	HTMLOutputElement: HTMLElement,
	HTMLPictureElement: HTMLElement,
	HTMLProgressElement: HTMLElement,
	HTMLQuoteElement: HTMLElement,
	HTMLScriptElement: HTMLScriptElement,
	HTMLSelectElement: HTMLElement,
	HTMLSlotElement: HTMLElement,
	HTMLSourceElement: HTMLElement,
	HTMLSpanElement: HTMLElement,
	HTMLTableCaptionElement: HTMLElement,
	HTMLTableCellElement: HTMLElement,
	HTMLTableColElement: HTMLElement,
	HTMLTableElement: HTMLElement,
	HTMLTimeElement: HTMLElement,
	HTMLTableRowElement: HTMLElement,
	HTMLTableSectionElement: HTMLElement,
	HTMLUnknownElement: HTMLElement,
	HTMLFrameElement: HTMLElement,
	HTMLFrameSetElement: HTMLElement,
	HTMLIFrameElement: HTMLElement,
	HTMLEmbedElement: HTMLElement,
	HTMLObjectElement: HTMLElement,
	HTMLParamElement: HTMLElement,
	HTMLVideoElement: HTMLElement,
	HTMLAudioElement: HTMLElement,
	HTMLTrackElement: HTMLElement,
	SVGSVGElement: SVGSVGElement,
	SVGElement: SVGElement
};
